#
# Makefile Template for Tessy
# Compiler: IAR RL78
# Debugger: IAR C-SPY Simulator
# Template Version: 2
#

# Defines to be generated by Tessy:
#
# BUFFER_SIZE           :=
# COMPILER_DEFINES      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# CPU                   :=
# CSTACK_SIZE           :=
# CODE_MODEL            :=
# COMPILER_DEFINES      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# CONFIG_HEADER_FILE    :=
# DATA_MODEL            :=
# ENDIANESS             :=
# EXEFILE_EXTENSION     :=
# HEAP_SIZE             :=
# LIBRARY               :=
# LINKER_FILE           :=
# MODULE_PATH           :=
# MODULE_PATH_DOS       :=
# OBJFILE_EXTENSION     :=
# PROJECTROOT           :=
# SSTACK_SIZE           :=
# TARGET_INSTALL_PATH   :=
# TESSY_BIN             :=
# TESSY_SYS             :=
# TESTOBJECT            :=
# TIMER_FILE            :=
# TARGET_INSTALL_PATH   :=
# TIMER_FILE            :=
# USER_LINK_OPTIONS     :=

#####################################################################
#BEGIN_DEFINES
#####################################################################

#
# Special macros for includes and defines
#
TS_DEF_SEPARATOR :=-D
define TS_DEFINE
$(subst ;, $(TS_DEF_SEPARATOR),$(1))
endef

TS_INC_SEPARATOR :=-I 
define TS_INCLUDE
$(subst ;, $(TS_INC_SEPARATOR),$(1))
endef


TESSY_SYS_DOS  := $(shell ts_pathname -s $(TESSY_SYS))
IAR_HOME       := $(shell ts_pathname -s '$(COMPILER_INSTALL_PATH)')

TS_NAME        := TS_CSPY
IDE_NAME       := cspy
COMPANY_NAME   := iar
PROCESSOR_NAME := rl78

ifeq ("little","$(ENDIANESS)")
  TS_BYTEORDER := TS_HOST_BYTEORDER
endif
ifeq ("big","$(ENDIANESS)")
  TS_BYTEORDER := TS_NET_BYTEORDER
endif
ifndef TS_BYTEORDER
  $(error Attribute 'Endianess' has invalid value '$(ENDIANESS)', only 'little' and 'big' are allowed.)
endif

all	 : master slave
master : $(MODULE_PATH)/ts_$(TESTOBJECT)_m.exe
slave  : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(EXEFILE_EXTENSION)

#
# MASTER & COMM Makefiles
# (you should not need to modify these settings)
#
M_COMM_MAKE    := $(TESSY_SYS)/make/master_$(IDE_NAME)_gnu_i386.mk
S_COMM_MAKE    := $(TESSY_SYS)/src/comm/comm_$(IDE_NAME)_$(COMPANY_NAME)_$(PROCESSOR_NAME).mk


#
# SLAVE
#

S_CC           := $(IAR_HOME)\bin\iccrl78.exe
S_LINK         := $(IAR_HOME)\bin\xlink.exe
S_STUB_OBJECT  := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs$(OBJFILE_EXTENSION)
S_UC_OBJECT    := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr$(OBJFILE_EXTENSION)

# (You may change these settings to use your own compiler/linker options)
S_COMP_OPTIONS := --core $(CORE) --code_model $(CODE_MODEL) --data_model $(DATA_MODEL) \
                  --near_const_location $(NEAR_CONST_LOCATION_COMPILER) --dlib_config "$(CONFIG_HEADER_FILE)" -e -Ohz --no_cse --no_unroll --no_inline \
                  --no_code_motion --no_tbaa --no_crosscall --no_scheduling --debug \
                  -DTESSY -DTS_SLAVE -D$(TS_NAME) -DTS_HAVE_FLOAT32
S_LINK_OPTIONS := -I$(IAR_HOME)\LIB\ -f "$(LINKER_FILE)" -rt -s __program_start \
                  -D_NEAR_CONST_LOCATION=$(NEAR_CONST_LOCATION) -D_NEAR_CONST_LOCATION_START=$(NEAR_CONST_LOCATION_START) \
                  -D_NEAR_CONST_LOCATION_END=$(NEAR_CONST_LOCATION_END) "$(LIBRARY)" -e_PrintfSmall=_Printf \
                  -e_ScanfSmall=_Scanf -D_CSTACK_SIZE=$(C_STACK_SIZE) -D_NEAR_HEAP_SIZE=$(NEAR_HEAP_SIZE) -D_FAR_HEAP_SIZE=$(FAR_HEAP_SIZE)\
                  -D_FAR_HEAP_SIZE=$(FAR_HEAP_SIZE)
S_INCLUDES     := -I $(IAR_HOME)\inc\ -I $(IAR_HOME)\inc\clib\ -I $(TESSY_SYS_DOS)\include\tessy\comm\ -I $(MODULE_PATH_DOS)\

#####################################################################
#END_DEFINES
#####################################################################

#####################################################################
#BEGIN_SOURCE
#####################################################################

#
# Template rules
#
$(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER)$(OBJFILE_EXTENSION): $(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER).c
	$(S_CC) -o $@ $(S_INCLUDES) $(call TS_INCLUDE,$(USER_INCLUDES$$(SOURCENUMBER))) $(S_COMP_OPTIONS) \
		$(call TS_DEFINE,$(USER_DEFINES$$(SOURCENUMBER))$(S_COM_OPTIONS)) \
		$(USER_COMP_OPTIONS$$(SOURCENUMBER)) "$<"


#####################################################################
#END_SOURCE
#####################################################################

#####################################################################
#BEGIN_TARGETS
#####################################################################


# Don't show action lines
# COMPILE USERCODE / STUBS
#
$(S_UC_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.c
	$(S_CC) -o $@ $(S_INCLUDES) $(S_COMP_OPTIONS) $<

$(S_STUB_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.c
	$(S_CC) -o $@ $(S_INCLUDES) $(S_COMP_OPTIONS) $<

#
# COMPILE/LINK MASTER
#

include $(M_COMM_MAKE)


#
# COMPILE SLAVE COMMUNICATION MODULES

include $(S_COMM_MAKE)


#
# COMPILE/LINK SLAVE
#
$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.c
	@echo *
	@echo ***** Compiling Slave *****
	$(S_CC) -o $@ $(S_INCLUDES) $(S_COMP_OPTIONS) $<


$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(EXEFILE_EXTENSION) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) \
																			$(S_SRC_OBJECTS) \
																			$(S_UC_OBJECT) \
																			$(S_STUB_OBJECT) \
																			$(S_C1_OBJECTS) \
																			$(S_OBJECTS)
	@echo *
	@echo ***** Linking Slave *****
	$(S_LINK) $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) $(S_STUB_OBJECT) $(S_UC_OBJECT) \
	$(S_SRC_OBJECTS) $(S_C1_OBJECTS) $(USER_LINK_OPTIONS) $(S_OBJECTS) -o "$@" $(S_LINK_OPTIONS)
	@-ts_rm -f "$(MODULE_PATH)"/*$(OBJFILE_EXTENSION)


#####################################################################
#END_TARGETS
#####################################################################












